<?php
/**
 * Theme widgets.
 *
 * @package The Blogging
 */

// Load widget base.
require_once get_template_directory() . '/inc/widgets/widget-base-class.php';

if (!function_exists('the_blogging_load_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function the_blogging_load_widgets()
    {
        // Recent Post widget.
        register_widget('TWP_sidebar_widget');

        // Auther widget.
        register_widget('TWP_Author_Post_widget');

        // Social widget.
        register_widget('TWP_Social_widget');

        register_widget('TWP_Tabbed_Widget');

    }
endif;
add_action('widgets_init', 'the_blogging_load_widgets');

/*Grid Panel widget*/
if (!class_exists('TWP_sidebar_widget')) :

    /**
     * Popular widget Class.
     *
     * @since 1.0.0
     */
    class TWP_sidebar_widget extends The_Blogging_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'the_blogging_popular_post_widget',
                'description' => __('Displays post form selected category specific for popular post in sidebars.', 'the-blogging'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => __('Title:', 'the-blogging'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => __('Select Category:', 'the-blogging'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => __('All Categories', 'the-blogging'),
                ),
                'enable_counter' => array(
                    'label' => __('Enable Counter:', 'the-blogging'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'post_number' => array(
                    'label' => __('Number of Posts:', 'the-blogging'),
                    'type' => 'number',
                    'default' => 4,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 5,
                ),
            );

            parent::__construct('the-blogging-popular-sidebar-layout', __('TWP: Recent Post', 'the-blogging'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if (!empty($params['title'])) {
                echo $args['before_title'] . $params['title'] . $args['after_title'];
            }

            $qargs = array(
                'posts_per_page' => esc_attr($params['post_number']),
                'no_found_rows' => true,
            );
            if (absint($params['post_category']) > 0) {
                $qargs['category'] = absint($params['post_category']);
            }
            $all_posts = get_posts($qargs);
            ?>
            <?php global $post; 
            $count = 1;
            ?>
            <?php if (!empty($all_posts)) : ?>
            <div class="twp-recent-widget">                
                <ul class="recent-widget-list">
                <?php foreach ($all_posts as $key => $post) : ?>
                    <?php setup_postdata($post); ?>
                    <li>
                        <article class="article-list">
                            <div class="row row-sm">
                                <div class="col-xs-3">
                                    <div class="article-image">
                                        <?php if (has_post_thumbnail()) {
                                            $thumb = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'the-blogging-900-600' );
                                            $url = $thumb['0'];
                                            } else {
                                                $url = '';
                                        }
                                        ?>
                                        <a href="<?php the_permalink(); ?>" class="bg-image bg-image-light bg-image-1">
                                            <img src="<?php echo esc_url($url); ?>" alt="<?php the_title_attribute(); ?>">
                                        </a>
                                        <?php if (true === $params['enable_counter']) { ?>
                                        <div class="trend-item">
                                            <span class="number">
                                                <?php echo $count; ?>
                                            </span>
                                        </div>
                                    <?php } ?>
                                    </div>
                                </div>
                                <div class="col-xs-9">
                                    <div class="article-body">
                                        <div class="entry-meta">
                                            <span class="posted-on primary-font">
                                                <?php the_time('j M Y'); ?>
                                            </span>
                                        </div>
                                        <h3 class="entry-title entry-title-small">
                                            <a href="<?php the_permalink(); ?>">
                                                <?php the_title(); ?>
                                            </a>
                                        </h3>
                                    </div>
                                </div>
                            </div>
                        </article>
                    </li>
                <?php 
                $count++;
                endforeach; ?>
                </ul>
            </div>

            <?php wp_reset_postdata(); ?>

        <?php endif; ?>
            <?php echo $args['after_widget'];
        }
    }
endif;

/*Video widget*/
if (!class_exists('TWP_Author_Post_widget')) :

    /**
     * Author widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Author_Post_widget extends The_Blogging_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'the_blogging_author_widget',
                'description' => __('Displays authors details in post.', 'the-blogging'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => __('Title:', 'the-blogging'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'image_bg_url' => array(
                    'label' => __('Widget Background Image:', 'the-blogging'),
                    'type'  => 'image',
                ),
                'author-name' => array(
                    'label' => __('Name:', 'the-blogging'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'description' => array(
                    'label' => __('Description:', 'the-blogging'),
                    'type'  => 'textarea',
                    'class' => 'widget-content widefat'
                ),
                'image_url' => array(
                    'label' => __('Author Image:', 'the-blogging'),
                    'type'  => 'image',
                ),
                'url-fb' => array(
                   'label' => __('Facebook URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-tw' => array(
                   'label' => __('Twitter URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-lt' => array(
                   'label' => __('Linkedin URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-ig' => array(
                   'label' => __('Instagram URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
            );

            parent::__construct('the-blogging-author-layout', __('TWP: Author Widget', 'the-blogging'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if ( ! empty( $params['title'] ) ) {
                echo $args['before_title'] . $params['title'] . $args['after_title'];
            } ?>

            <!--cut from here-->
            <div class="author-info">
                <?php if ( ! empty( $params['image_bg_url'] ) ) { ?>
                    <div class="author-background bg-image bg-image-light">
                        <img src="<?php echo esc_url( $params['image_bg_url'] ); ?>">
                    </div>
                <?php } ?>
                <div class="author-image">
                    <?php if ( ! empty( $params['image_url'] ) ) { ?>
                        <div class="profile-image bg-image">
                            <img src="<?php echo esc_url( $params['image_url'] ); ?>">
                        </div>
                    <?php } ?>
                </div>
                <div class="author-details">
                    <?php if ( ! empty( $params['author-name'] ) ) { ?>
                        <h3 class="author-name"><?php echo esc_html($params['author-name'] );?></h3>
                    <?php } ?>
                    <?php if ( ! empty( $params['description'] ) ) { ?>
                        <div class="author-bio"><?php echo wp_kses_post( $params['description']); ?></div>
                    <?php } ?>
                </div>
                <div class="author-social">
                    <?php if ( ! empty( $params['url-fb'] ) ) { ?>
                        <a href="<?php echo esc_url($params['url-fb']); ?>"><i class="meta-icon ion-social-facebook"></i></a>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-tw'] ) ) { ?>
                        <a href="<?php echo esc_url($params['url-tw']); ?>"><i class="meta-icon ion-social-twitter"></i></a>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-lt'] ) ) { ?>
                        <a href="<?php echo esc_url($params['url-lt']); ?>"><i class="meta-icon ion-social-linkedin"></i></a>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-ig'] ) ) { ?>
                        <a href="<?php echo esc_url($params['url-ig']); ?>"><i class="meta-icon ion-social-instagram"></i></a>
                    <?php } ?>
                </div>
            </div>
            <?php echo $args['after_widget'];
        }
    }
endif;

/*Social widget*/
if (!class_exists('TWP_Social_widget')) :

    /**
     * Social widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Social_widget extends The_Blogging_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'the_blogging_social_widget',
                'description' => __('Displays Social share.', 'the-blogging'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => __('Title:', 'the-blogging'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'url-fb' => array(
                   'label' => __('Facebook URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-tw' => array(
                   'label' => __('Twitter URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-lt' => array(
                   'label' => __('Linkedin URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-ig' => array(
                   'label' => __('Instagram URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-pt' => array(
                   'label' => __('Pinterest URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-rt' => array(
                   'label' => __('Reddit URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-sk' => array(
                   'label' => __('Skype URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-sc' => array(
                   'label' => __('Snapchat URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-tr' => array(
                   'label' => __('Tumblr URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-th' => array(
                   'label' => __('Twitch URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-yt' => array(
                   'label' => __('Youtube URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-vo' => array(
                   'label' => __('Vimeo URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-wa' => array(
                   'label' => __('Whatsapp URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-wp' => array(
                   'label' => __('WordPress URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-gh' => array(
                   'label' => __('Github URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-fs' => array(
                   'label' => __('FourSquare URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
                'url-db' => array(
                   'label' => __('Dribbble URL:', 'the-blogging'),
                   'type' => 'url',
                   'class' => 'widefat',
                    ),
            );

            parent::__construct('the-blogging-social-layout', __('TWP: Social Widget', 'the-blogging'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if ( ! empty( $params['title'] ) ) {
                echo $args['before_title'] . $params['title'] . $args['after_title'];
            } ?>

            <div class="twp-social-widget">
                <ul class="social-widget-wrapper">
                    <?php if ( ! empty( $params['url-fb'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-fb']); ?>" target="_blank"><i class="meta-icon ion-social-facebook"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-tw'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-tw']); ?>" target="_blank"><i class="social-icon ion-social-twitter"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-lt'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-lt']); ?>" target="_blank"><i class="social-icon ion-social-linkedin"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-ig'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-ig']); ?>" target="_blank"><i class="social-icon ion-social-instagram"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-pt'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-pt']); ?>" target="_blank"><i class="social-icon ion-social-pinterest"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-rt'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-rt']); ?>" target="_blank"><i class="social-icon ion-social-reddit"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-sk'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-sk']); ?>" target="_blank"><i class="social-icon ion-social-skype"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-sc'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-sc']); ?>" target="_blank"><i class="social-icon ion-social-snapchat"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-tr'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-tr']); ?>" target="_blank"><i class="social-icon ion-social-tumblr"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-th'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-th']); ?>" target="_blank"><i class="social-icon ion-social-twitch"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-yt'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-yt']); ?>" target="_blank"><i class="social-icon ion-social-youtube"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-vo'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-vo']); ?>" target="_blank"><i class="social-icon ion-social-vimeo"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-wa'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-wa']); ?>" target="_blank"><i class="social-icon ion-social-whatsapp"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-wp'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-wp']); ?>" target="_blank"><i class="social-icon ion-social-wordpress"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-gh'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-gh']); ?>" target="_blank"><i class="social-icon ion-social-github"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-fs'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-fs']); ?>" target="_blank"><i class="social-icon ion-social-foursquare"></i></a>
                        </li>
                    <?php } ?>
                    <?php if ( ! empty( $params['url-db'] ) ) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-db']); ?>" target="_blank"><i class="social-icon ion-social-dribbble"></i></a>
                        </li>
                    <?php } ?>
                </ul>
            </div>
            <?php echo $args['after_widget'];
        }
    }
endif;

/*tabed widget*/
if (!class_exists('TWP_Tabbed_Widget')):

    /**
     * Tabbed widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Tabbed_Widget extends The_Blogging_Widget_Base {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct() {

            $opts = array(
                'classname'   => 'the_blogging_widget_tabbed',
                'description' => __('Tabbed widget.', 'the-blogging'),
            );
            $fields = array(
                'popular_heading' => array(
                    'label'          => __('Popular', 'the-blogging'),
                    'type'           => 'heading',
                ),
                'popular_number' => array(
                    'label'         => __('No. of Posts:', 'the-blogging'),
                    'type'          => 'number',
                    'css'           => 'max-width:60px;',
                    'default'       => 5,
                    'min'           => 1,
                    'max'           => 10,
                ),
                'enable_discription' => array(
                    'label'             => __('Enable Description:', 'the-blogging'),
                    'type'              => 'checkbox',
                    'default'           => true,
                ),
                'select_image_size' => array(
                    'label' => __('Select Image Size Featured Post:', 'the-blogging'),
                    'type' => 'select',
                    'default' => 'medium',
                    'options' => array(
                        'thumbnail' => esc_html__( 'Thumbnail', 'the-blogging' ),
                        'medium' => esc_html__( 'Medium', 'the-blogging' ),
                        'large' => esc_html__( 'Large', 'the-blogging' ),
                        'full' => esc_html__( 'Full', 'the-blogging' ),
                        ),
                    
                ),
                'excerpt_length' => array(
                    'label'         => __('Excerpt Length:', 'the-blogging'),
                    'description'   => __('Number of words', 'the-blogging'),
                    'default'       => 10,
                    'css'           => 'max-width:60px;',
                    'min'           => 0,
                    'max'           => 200,
                ),
                'recent_heading' => array(
                    'label'         => __('Recent', 'the-blogging'),
                    'type'          => 'heading',
                ),
                'recent_number' => array(
                    'label'        => __('No. of Posts:', 'the-blogging'),
                    'type'         => 'number',
                    'css'          => 'max-width:60px;',
                    'default'      => 5,
                    'min'          => 1,
                    'max'          => 10,
                ),
                'comments_heading' => array(
                    'label'           => __('Comments', 'the-blogging'),
                    'type'            => 'heading',
                ),
                'comments_number' => array(
                    'label'          => __('No. of Comments:', 'the-blogging'),
                    'type'           => 'number',
                    'css'            => 'max-width:60px;',
                    'default'        => 5,
                    'min'            => 1,
                    'max'            => 10,
                ),
            );

            parent::__construct('the-blogging-tabbed', __('TWP: Tab Widgets', 'the-blogging'), $opts, array(), $fields);

        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance) {

            $params = $this->get_params($instance);
            $tab_id = 'tabbed-'.$this->number;

            echo $args['before_widget'];
            ?>
            <div class="tabbed-container">

                <div class="section-head">
                    <ul class="nav nav-tabs" role="tablist">
                        <li role="presentation" class="tab tab-popular active">
                            <a href="#<?php echo esc_attr($tab_id);?>-popular" aria-controls="<?php esc_html_e('Popular', 'the-blogging');?>" role="tab" data-toggle="tab">
                                <span class="fire-icon tab-icon">
                                    <svg version="1.1" id="fire-icon" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" fill="currentcolor" viewBox="0 0 611.999 611.999" style="enable-background:new 0 0 611.999 611.999;" xml:space="preserve">
                                        <g>
                                            <path d="M216.02,611.195c5.978,3.178,12.284-3.704,8.624-9.4c-19.866-30.919-38.678-82.947-8.706-149.952
                                                c49.982-111.737,80.396-169.609,80.396-169.609s16.177,67.536,60.029,127.585c42.205,57.793,65.306,130.478,28.064,191.029
                                                c-3.495,5.683,2.668,12.388,8.607,9.349c46.1-23.582,97.806-70.885,103.64-165.017c2.151-28.764-1.075-69.034-17.206-119.851
                                                c-20.741-64.406-46.239-94.459-60.992-107.365c-4.413-3.861-11.276-0.439-10.914,5.413c4.299,69.494-21.845,87.129-36.726,47.386
                                                c-5.943-15.874-9.409-43.33-9.409-76.766c0-55.665-16.15-112.967-51.755-159.531c-9.259-12.109-20.093-23.424-32.523-33.073
                                                c-4.5-3.494-11.023,0.018-10.611,5.7c2.734,37.736,0.257,145.885-94.624,275.089c-86.029,119.851-52.693,211.896-40.864,236.826
                                                C153.666,566.767,185.212,594.814,216.02,611.195z"/>
                                        </g>
                                    </svg>
                                </span>
                                <?php esc_html_e('Popular', 'the-blogging');?>
                            </a>
                        </li>
                        <li class="tab tab-recent">
                            <a href="#<?php echo esc_attr($tab_id);?>-recent" aria-controls="<?php esc_html_e('Recent', 'the-blogging');?>" role="tab" data-toggle="tab">
                                <span class="flash-icon tab-icon">
                                    <svg version="1.1" id="flash-icon" xmlns="http://www.w3.org/2000/svg" fill="currentcolor" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 612 612" style="enable-background:new 0 0 612 612;" xml:space="preserve">
                                        <g>
                                            <path d="M286.363,607.148l195.851-325.636c7.954-13.225-1.571-30.069-17.003-30.069H334.436L479.335,30.732
                                                C487.998,17.537,478.532,0,462.748,0H237.426c-8.806,0-16.558,5.804-19.039,14.253l-90.655,308.81
                                                c-3.73,12.706,5.796,25.431,19.039,25.431h176.915l-55.512,251.4C265.75,610.872,280.57,616.781,286.363,607.148z"/>
                                        </g>
                                    </svg>
                                </span>
                                <?php esc_html_e('Recent', 'the-blogging');?>
                            </a>
                        </li>
                        <li class="tab tab-comments">
                            <a href="#<?php echo esc_attr($tab_id);?>-comments" aria-controls="<?php esc_html_e('Comments', 'the-blogging');?>" role="tab" data-toggle="tab">
                                <span class="comment-icon tab-icon">
                                    <svg version="1.1" id="comment-icon" fill="currentcolor" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="18px" height="18px" viewBox="0 0 511.626 511.626" style="enable-background:new 0 0 511.626 511.626;" xml:space="preserve">
                                        <g>
                                            <path d="M477.371,127.44c-22.843-28.074-53.871-50.249-93.076-66.523c-39.204-16.272-82.035-24.41-128.478-24.41
                                                c-34.643,0-67.762,4.805-99.357,14.417c-31.595,9.611-58.812,22.602-81.653,38.97c-22.845,16.37-41.018,35.832-54.534,58.385
                                                C6.757,170.833,0,194.484,0,219.228c0,28.549,8.61,55.3,25.837,80.234c17.227,24.931,40.778,45.871,70.664,62.811
                                                c-2.096,7.611-4.57,14.846-7.426,21.693c-2.855,6.852-5.424,12.474-7.708,16.851c-2.286,4.377-5.376,9.233-9.281,14.562
                                                c-3.899,5.328-6.849,9.089-8.848,11.275c-1.997,2.19-5.28,5.812-9.851,10.849c-4.565,5.048-7.517,8.329-8.848,9.855
                                                c-0.193,0.089-0.953,0.952-2.285,2.567c-1.331,1.615-1.999,2.423-1.999,2.423l-1.713,2.566c-0.953,1.431-1.381,2.334-1.287,2.707
                                                c0.096,0.373-0.094,1.331-0.57,2.851c-0.477,1.526-0.428,2.669,0.142,3.433v0.284c0.765,3.429,2.43,6.187,4.998,8.277
                                                c2.568,2.092,5.474,2.95,8.708,2.563c12.375-1.522,23.223-3.606,32.548-6.276c49.87-12.758,93.649-35.782,131.334-69.097
                                                c14.272,1.522,28.072,2.286,41.396,2.286c46.442,0,89.271-8.138,128.479-24.417c39.208-16.272,70.233-38.448,93.072-66.517
                                                c22.843-28.062,34.263-58.663,34.263-91.781C511.626,186.108,500.207,155.509,477.371,127.44z"/>
                                        </g>
                                    </svg>
                                </span>
                                <?php esc_html_e('Comments', 'the-blogging');?>
                            </a>
                        </li>
                    </ul>
                </div>
                <div class="tab-content">
                    <div id="<?php echo esc_attr($tab_id);?>-popular" role="tabpanel" class="tab-pane active">
                        <?php $this->render_news('popular', $params);?>
                    </div>
                    <div id="<?php echo esc_attr($tab_id);?>-recent" role="tabpanel" class="tab-pane">
                        <?php $this->render_news('recent', $params);?>
                    </div>
                    <div id="<?php echo esc_attr($tab_id);?>-comments" role="tabpanel" class="tab-pane">
                        <?php $this->render_comments($params);?>
                    </div>
                </div>
            </div>
            <?php

            echo $args['after_widget'];

        }

        /**
         * Render news.
         *
         * @since 1.0.0
         *
         * @param array $type Type.
         * @param array $params Parameters.
         * @return void
         */
        function render_news($type, $params) {

            if (!in_array($type, array('popular', 'recent'))) {
                return;
            }

            switch ($type) {
                case 'popular':
                    $qargs = array(
                        'posts_per_page' => $params['popular_number'],
                        'no_found_rows'  => true,
                        'orderby'        => 'comment_count',
                    );
                    break;

                case 'recent':
                    $qargs = array(
                        'posts_per_page' => $params['recent_number'],
                        'no_found_rows'  => true,
                    );
                    break;

                default:
                    break;
            }

            $all_posts = get_posts($qargs);
            ?>
            <?php if (!empty($all_posts)):?>
                <?php global $post;
                ?>
                <ul class="article-item article-list-item article-tabbed-list">
                    <?php foreach ($all_posts as $key => $post):?>
                        <?php setup_postdata($post);?>
                        <li class="full-item">
                            <div class="row row-sm">
                                <div class="col-sm-4">
                                    <div class="article-image">
                                        <a href="<?php the_permalink();?>" class="article-bg-list bg-image-light bg-image">
                                            <?php if (has_post_thumbnail($post->ID)){?>
                                                <?php
                                                $select_image_size = esc_attr($params['select_image_size']);
                                                $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), $select_image_size);?>
                                                <?php if (!empty($image)):?>
                                                    <img src="<?php echo esc_url($image[0]);?>"/>
                                                <?php endif;?>
                                            <?php  } ?>
                                        </a>
                                    </div>
                                </div>
                                <div class="col-sm-8">
                                    <div class="full-item-details">
                                        <div class="full-item-content">
                                            <div class="entry-meta">
                                                <span class="posted-on primary-font">
                                                   <?php the_time('F j, Y'); ?>
                                                </span>
                                            </div>
                                            <h3 class="entry-title entry-title-small">
                                                <a href="<?php the_permalink();?>">
                                                    <?php the_title();?>
                                                </a>
                                            </h3>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="row row-sm">
                                <div class="col-sm-12">
                                    <?php if (true === $params['enable_discription']) {?>
                                        <?php if (absint($params['excerpt_length']) > 0):?>
                                            <div class="post-description">
                                                <?php
                                                $excerpt = the_blogging_words_count(absint($params['excerpt_length']), get_the_content());
                                                echo wp_kses_post(wpautop($excerpt));
                                                ?>
                                            </div>
                                        <?php endif;?>
                                    <?php }?>
                                </div>
                            </div>
                        </li>
                    <?php endforeach;?>
                </ul><!-- .news-list -->

                <?php wp_reset_postdata();?>

            <?php endif;?>

            <?php

        }

        /**
         * Render comments.
         *
         * @since 1.0.0
         *
         * @param array $params Parameters.
         * @return void
         */
        function render_comments($params) {

            $comment_args = array(
                'number'      => $params['comments_number'],
                'status'      => 'approve',
                'post_status' => 'publish',
            );

            $comments = get_comments($comment_args);
            ?>
            <?php if (!empty($comments)):?>
                <ul class="article-item article-list-item comments-tabbed-list">
                    <?php foreach ($comments as $key => $comment):?>
                        <li class="full-item">
                            <div class="row row-sm">
                                <div class="col-sm-4">
                                    <figure class="article-thumbmnail">
                                        <?php $comment_author_url = get_comment_author_url($comment);?>
                                        <?php if (!empty($comment_author_url)):?>
                                            <a href="<?php echo esc_url($comment_author_url);?>"><?php echo get_avatar($comment, 65);
                                                ?></a>
                                        <?php  else :?>
                                            <?php echo get_avatar($comment, 65);?>
                                        <?php endif;?>
                                    </figure>
                                </div>
                                <div class="col-sm-8">
                                    <div class="comments-content">
                                        <?php echo get_comment_author_link($comment);?>
                                        &nbsp;
                                        <?php echo esc_html_x('on', 'Tabbed Widget', 'the-blogging');
                                        ?>&nbsp;
                                        <a href="<?php echo esc_url(get_comment_link($comment));?>">
                                            <?php echo get_the_title($comment->comment_post_ID);?>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </li>
                    <?php endforeach;?>
                </ul><!-- .comments-list -->
            <?php endif;?>
            <?php
        }

    }
endif;
